@@ -301,11 +301,17 @@ shinyServer(function(input, output, session) {
     var_names <- names(datClean())
     if (input$dat_type == "dat" || input$dat_type == "xlsx") {
       
+      b_clu_agg_choices <- if (input$calcPhasePair) {
+        c(var_names, "phase_pair_calculated")
+      } else {
+        var_names
+      }
+      
       list(
-        selectizeInput("b_clusters", label = "Select all variables uniquely identifying cases (e.g. pseudonym, study, behavior).", choices = var_names, 
-                       selected = NULL, multiple = TRUE),
-        selectizeInput("b_aggregate", label = "Select all variables to average across after calculating effect size estimates.", choices = var_names,
-                       selected = NULL, multiple = TRUE),
+        selectizeInput("b_clusters", label = "Select all variables uniquely identifying cases (e.g. pseudonym, study, behavior).", 
+                       choices = b_clu_agg_choices, selected = NULL, multiple = TRUE),
+        selectizeInput("b_aggregate", label = "Select all variables to average across after calculating effect size estimates.", 
+                       choices = b_clu_agg_choices, selected = NULL, multiple = TRUE),
         selectInput("b_phase", label = "Phase indicator", choices = var_names, selected = var_names[3])
       )
       
@@ -314,9 +320,11 @@ shinyServer(function(input, output, session) {
       curMap <- exampleMapping[[input$example]]
       
       list(
-        selectizeInput("b_clusters", label = "Select all variables uniquely identifying cases (e.g. pseudonym, study, behavior).", choices = var_names, 
+        selectizeInput("b_clusters", label = "Select all variables uniquely identifying cases (e.g. pseudonym, study, behavior).", 
+                       choices = var_names, 
                        selected = curMap$cluster_vars, multiple = TRUE),
-        selectizeInput("b_aggregate", label = "Select all variables to average across after calculating effect size estimates.", choices = var_names,
+        selectizeInput("b_aggregate", label = "Select all variables to average across after calculating effect size estimates.", 
+                       choices = var_names,
                        selected = curMap$aggregate_vars, multiple = TRUE),
         selectInput("b_phase", label = "Phase indicator", choices = var_names, selected = curMap$condition)
       )
@@ -435,7 +443,29 @@ shinyServer(function(input, output, session) {
     }
   }) 
   
-  output$datview2 <- renderTable(datClean())
+  datClean2 <- reactive({
+    dat <- datClean()
+    
+    if (input$calcPhasePair) {
+      grouping_vars <- setdiff(input$b_clusters, "phase_pair_calculated")
+      session_var <- input$session_number
+      phase_var <- input$b_phase
+      
+      dat <- 
+        dat %>% 
+        dplyr::group_by(!!!rlang::syms(grouping_vars)) %>% 
+        dplyr::mutate(
+          phase_pair_calculated = calc_phase_pairs(!!rlang::sym(phase_var), session = !!rlang::sym(session_var))
+        ) %>% 
+        dplyr::ungroup() %>% 
+        as.data.frame() 
+    }
+    
+    return(dat)
+    
+  })
+  
+  output$datview2 <- renderTable(datClean2())
   
   # Plot
   output$facetSelector <- renderUI({
@@ -452,7 +482,7 @@ shinyServer(function(input, output, session) {
     
     if (length(grouping_vars) > 0) {
       
-      grouping_vals <- lapply(grouping_vars, function(x) levels(as.factor(datClean()[,x])))
+      grouping_vals <- lapply(grouping_vars, function(x) levels(as.factor(datClean2()[,x])))
       names(grouping_vals) <- grouping_vars
       
       header <- strong("Select a value for each grouping variable.")
@@ -471,14 +501,14 @@ shinyServer(function(input, output, session) {
   
   datGraph <- reactive({
     
-    dat <- datClean()
+    dat <- datClean2()
     
     if (!is.null(input$b_clusters) | !is.null(input$b_aggregate)) {
 
       grouping_vars <- setdiff(c(input$b_clusters, input$b_aggregate), input$bfacetSelector)
       
       if (length(grouping_vars) > 0) {
-        subset_vals <- sapply(grouping_vars, function(x) datClean()[[x]] %in% input[[paste0("grouping_",x)]])
+        subset_vals <- sapply(grouping_vars, function(x) datClean2()[[x]] %in% input[[paste0("grouping_",x)]])
         dat <- dat[apply(subset_vals, 1, all),]
       } 
       
@@ -488,7 +518,6 @@ shinyServer(function(input, output, session) {
     
   })
   
-  # output$datview3 <- renderTable(datGraph2())
   
   heightPlot <- reactive({
     if (input$bfacetSelector == "None") {
@@ -509,7 +538,7 @@ shinyServer(function(input, output, session) {
     if (input$bfacetSelector == "None") {
       
       dat_graph <-
-        data.frame(session = session_dat, outcome = outcome_dat, phase = phase_dat) %>%
+        data.frame(session = session_dat, outcome = outcome_dat, phase = as.factor(phase_dat)) %>%
         dplyr::filter(phase %in% c(input$b_base, input$b_treat))
       
       phase_change <-
@@ -524,7 +553,7 @@ shinyServer(function(input, output, session) {
       facet_dat <- dat[[input$bfacetSelector]]
       
       dat_graph <-
-        data.frame(facet = facet_dat, session = session_dat, outcome = outcome_dat, phase = phase_dat) %>%
+        data.frame(facet = facet_dat, session = session_dat, outcome = outcome_dat, phase = as.factor(phase_dat)) %>%
         dplyr::filter(phase %in% c(input$b_base, input$b_treat))
       
       phase_change <-
@@ -555,8 +584,14 @@ shinyServer(function(input, output, session) {
       } else{
         scale_val <- input$boutScale
       }
+      
+      intervals <- if (input$bintervals == "NA") NA else input$bintervals
+      obslength <- if (input$bobslength == "NA") NA else input$bobslength
+      D_const <- if (is.null(input$blrrfloor)) NA else input$blrrfloor
+      
     } else {
       scale_val <- "other"
+      intervals <- obslength <- D_const <- NA
     }
     
     if(input$bimprovement == "series") {
@@ -579,7 +614,7 @@ shinyServer(function(input, output, session) {
     
     if (is.null(input$b_aggregate)) {
       
-      batch_calc_ES(dat = datClean(),
+      batch_calc_ES(dat = datClean2(),
                     grouping = input$b_clusters,
                     condition = input$b_phase,
                     outcome = input$b_out,
@@ -590,6 +625,9 @@ shinyServer(function(input, output, session) {
                     improvement = improvement,
                     pct_change = input$b_pct_change,
                     scale = scale_val,
+                    intervals = intervals,
+                    observation_length = obslength,
+                    D_const = D_const,
                     std_dev = input$bSMD_denom,
                     confidence = input$bconfidence / 100,
                     Kendall = Kendall, 
@@ -599,7 +637,7 @@ shinyServer(function(input, output, session) {
       
     } else{
       
-      batch_calc_ES(dat = datClean(),
+      batch_calc_ES(dat = datClean2(),
                     grouping = input$b_clusters,
                     condition = input$b_phase,
                     outcome = input$b_out,
@@ -612,6 +650,9 @@ shinyServer(function(input, output, session) {
                     improvement = improvement,
                     pct_change = input$b_pct_change,
                     scale = scale_val,
+                    intervals = intervals,
+                    observation_length = obslength,
+                    D_const = D_const,
                     std_dev = input$bSMD_denom,
                     confidence = input$bconfidence / 100,
                     Kendall = Kendall, 
@@ -626,6 +667,8 @@ shinyServer(function(input, output, session) {
 
   })
   
+  output$batchTable <- renderTable(batchModel(), na = "-", digits = function() input$bdigits)
+
   output$downloadES <- downloadHandler(
     filename = "SCD effect size estimates.csv",
     content = function(file) {
@@ -635,8 +678,6 @@ shinyServer(function(input, output, session) {
     contentType = "text/csv"
   )
   
-  output$batchTable <- renderTable(batchModel(), na = "-")
-  
   #------------------------------
   # Syntax for replication in R
   #------------------------------
@@ -686,24 +727,52 @@ shinyServer(function(input, output, session) {
       clean_dat <- c()
     } 
     
+    # clean the data
+    if (input$calcPhasePair) {
+      grouping <- paste(input$b_clusters, collapse=', ')
+      condition <- input$b_phase
+      session_number <- input$session_number
+      
+      clean_dat <- c(clean_dat,
+                      parse_code_chunk("dat-clean", 
+                                       args = list(user_grouping = grouping,
+                                                   user_condition = condition,
+                                                   user_session_number = session_number)),
+                      ''
+      )
+    }
+    
     
     # batch calculation
     if (any(input$bESpar %in% c("LRRi", "LRRd", "LOR"))) {
-      if (input$boutScale == "series") {
-        scale_val <- input$bscalevar
-      } else{
-        scale_val <- input$boutScale
-      }
+      
+      scale_val <- switch(input$boutScale,
+        "series" = paste0("\n                     scale = ", as.symbol(input$bscalevar), ","),
+        "percentage" = '\n            scale = "percentage",',
+        "proportion" = '\n            scale = "proportion",',
+        "count" = '\n                 scale = "count",',
+        "rate" = '\n                  scale = "rate",',
+        "other" = '\n                 scale = "other",',
+        c()
+      )
+      
+      intervals <- if (input$bintervals == "NA") NA else input$bintervals
+      obslength <- if (input$bobslength == "NA") NA else input$bobslength
+      D_const <- if (is.null(input$blrrfloor)) NA else input$blrrfloor
+      
     } else {
-      scale_val <- "other"
-    }
-
-    if (input$bimprovement == "series") {
-      improvement <- input$bseldir
-    } else {
-      improvement <- input$bimprovement
+      # scale_val <- "other"
+      scale_val <- '\n                scale = "other",'
+      intervals <- obslength <- D_const <- NA
     }
     
+    improvement <- switch(input$bimprovement,
+                          "series" = paste0("\n                     improvement = ", as.symbol(input$bseldir), ","),
+                          "increase" = '\n                     improvement = "increase",',
+                          "decrease" = '\n                     improvement = "decrease",',
+                          c()
+    )
+    
     if (input$btau_calculation == "Kendall") {
       Kendall <- TRUE
     } else {
@@ -725,9 +794,10 @@ shinyServer(function(input, output, session) {
     baseline_phase <- input$b_base
     intervention_phase <- input$b_treat
     ES <- paste0('c("', paste(c(input$bESno, input$bESpar), collapse='", "'), '")')
-    improvement <- improvement
     pct_change <- input$b_pct_change
-    scale <- scale_val
+    intervals <- intervals
+    obslength <- obslength
+    D_const <- D_const
     std_dev <- input$bSMD_denom
     confidence <- input$bconfidence / 100
     Kendall <- Kendall
@@ -747,7 +817,10 @@ shinyServer(function(input, output, session) {
                                        user_ES = ES,
                                        user_improvement = improvement,
                                        user_pct_change = pct_change,
-                                       user_scale = scale,
+                                       user_scale = scale_val,
+                                       user_intervals = intervals,
+                                       user_obslength = obslength,
+                                       user_D_const = D_const,
                                        user_std_dev = std_dev,
                                        user_confidence = confidence,
                                        user_Kendall = Kendall,
@@ -769,7 +842,10 @@ shinyServer(function(input, output, session) {
                                        user_ES = ES,
                                        user_improvement = improvement,
                                        user_pct_change = pct_change,
-                                       user_scale = scale,
+                                       user_scale = scale_val,
+                                       user_intervals = intervals,
+                                       user_obslength = obslength,
+                                       user_D_const = D_const,
                                        user_std_dev = std_dev,
                                        user_confidence = confidence,
                                        user_Kendall = Kendall,
